@@ -64,7 +64,11 @@ class MockInvocation(iwyu_tool.Invocation):
 class MockIwyuToolMain(object):
     """ Replacement for iwyu_tool.main to capture parsed arguments. """
     def __init__(self):
-        self.argspec = inspect.getargspec(iwyu_tool.main).args
+        if hasattr(inspect, 'getfullargspec'):
+            getargspec = inspect.getfullargspec
+        else:
+            getargspec = inspect.getargspec
+        self.argspec = getargspec(iwyu_tool.main).args
         self.real_iwyu_tool_main = iwyu_tool.main
         iwyu_tool.main = self._mock
         self.call_args = {}
@@ -131,35 +135,48 @@ class IWYUToolTests(unittest.TestCase):
 
     def test_returncode(self):
         invocation = MockInvocation()
-        invocation.will_returncode(2)
+        invocation.will_returncode(0)
         self.assertEqual(self._execute([invocation]), 0)
         invocation = MockInvocation()
-        invocation.will_returncode(7)
+        invocation.will_returncode(1)
         self.assertEqual(self._execute([invocation]), 1)
+        invocation = MockInvocation()
+        invocation.will_returncode(2)
+        self.assertEqual(self._execute([invocation]), 2)
 
     def test_returncode_asynchronous(self):
         invocations = [MockInvocation() for _ in range(100)]
         for invocation in invocations:
-            invocation.will_returncode(2)
+            invocation.will_returncode(0)
             invocation.will_block(random.random() / 100)
         self.assertEqual(self._execute(invocations, jobs=100), 0)
         invocations = [MockInvocation() for _ in range(100)]
+        for invocation in invocations:
+            invocation.will_returncode(2)
+            invocation.will_block(random.random() / 100)
+        self.assertEqual(self._execute(invocations, jobs=100), 2)
+        invocations = [MockInvocation() for _ in range(100)]
         for n, invocation in enumerate(invocations):
             invocation.will_returncode(6 if n == 0 else 2)
             invocation.will_block(random.random() / 100)
-        self.assertEqual(self._execute(invocations, jobs=100), 1)
+        self.assertEqual(self._execute(invocations, jobs=100), 6)
 
-    def test_order_synchronous(self):
+    def test_returncode_synchronous(self):
+        invocations = [MockInvocation() for _ in range(1)]
+        for invocation in invocations:
+            invocation.will_returncode(0)
+            invocation.will_block(random.random() / 100)
+        self.assertEqual(self._execute(invocations, jobs=100), 0)
         invocations = [MockInvocation() for _ in range(1)]
         for invocation in invocations:
             invocation.will_returncode(2)
             invocation.will_block(random.random() / 100)
-        self.assertEqual(self._execute(invocations, jobs=100), 0)
+        self.assertEqual(self._execute(invocations, jobs=100), 2)
         invocations = [MockInvocation() for _ in range(1)]
         for n, invocation in enumerate(invocations):
             invocation.will_returncode(6 if n == 0 else 2)
             invocation.will_block(random.random() / 100)
-        self.assertEqual(self._execute(invocations, jobs=100), 1)
+        self.assertEqual(self._execute(invocations, jobs=100), 6)
 
     @unittest.skipIf(sys.platform.startswith('win'), "POSIX only")
     def test_is_subpath_of_posix(self):
